
# if (OLDPROTO) 
/***** Prototypes for image ***************/

void          PositionPictures    PROTO((Layout *, Graphic *));
void          CreateColorbar      PROTO((Layout *, Graphic *));
void          CreatePicture       PROTO((Layout *, Graphic *));
void          CreateZoom          PROTO((Layout *, Graphic *, double, double));
void          Remap               PROTO((Layout *, Matrix  *));
int           NewPicture          PROTO((Graphic *, Layout *));
void          Reorient            PROTO((Graphic *, Layout *, XButtonEvent *));
int           UpdatePointer       PROTO((Graphic *, Layout *, XMotionEvent *));
void          CrossHairs          PROTO((Graphic *, Layout *));
int           LoadOverlay         PROTO((Graphic *, Layout *));
int           SaveOverlay         PROTO((Graphic *, Layout *));
int           CSaveOverlay         PROTO((Graphic *, Layout *));
int           EraseOverlay        PROTO((Graphic *, Layout *));
void          StatusBox           PROTO((Graphic *, Layout *));
void          PaintOverlay        PROTO((Graphic *, Layout *, int));

/***** Prototypes for action ***************/

int           CheckPipe           PROTO((Graphic *, Layout *));
void          DefineLayout        PROTO((Layout *, Graphic *, int, char **));
int           EventLoop           PROTO((Graphic *, Layout *));
int           InPicture           PROTO((XButtonEvent *, Picture *));
int           InterpretKeys       PROTO((Graphic *, Layout *, XEvent *));
int           InterpretPresses    PROTO((Graphic *, Layout *, XButtonEvent *));
int           Reconfig            PROTO((Graphic *, Layout *, XEvent *));
void          Refresh             PROTO((Graphic *, Layout *, int));
int           Stop                PROTO((Graphic *, Layout *));
int           PSit                PROTO((Graphic *, Layout *));
int           get_argument        PROTO((int, char **, char *));
int           remove_argument     PROTO((int, int *, char **));
void          DragColorbar        PROTO((Graphic *, Layout *, XButtonEvent *));
void          ResetColorbar       PROTO((Graphic *, Layout *, double, double));
void          MakeColormap        PROTO((Graphic *, Layout *, int, char **));

/***** Prototypes for button ***************/

Button       *CheckButtons        PROTO((XButtonEvent *, Layout *));
void          DrawButton          PROTO((Graphic *, Button *));
void          FlashButton         PROTO((Graphic *, Button *));
int           InButton            PROTO((XButtonEvent *, Button *));
void          InvertButton        PROTO((Graphic *, Button *));
int           greycolors          PROTO((Graphic *, Layout *));
int           rainbow             PROTO((Graphic *, Layout *));
int           puns                PROTO((Graphic *, Layout *));
int           Recenter            PROTO((Graphic *, Layout *));
int           RecenterRescale     PROTO((Graphic *, Layout *));
int           Rescale             PROTO((Graphic *, Layout *));
int           ToggleDEG           PROTO((Graphic *, Layout *));
int           Overlay0            PROTO((Graphic *, Layout *));
int           Overlay1            PROTO((Graphic *, Layout *));
int           Overlay2            PROTO((Graphic *, Layout *));
int           Overlay3            PROTO((Graphic *, Layout *));

/***** Prototypes for xtools ***************/

void          CheckColors         PROTO((Graphic *, int *, char **));
void          CheckDisplayName    PROTO((int *, char **, char *));
void          CheckFontName       PROTO((int *, char **, char *));
void          CheckGeometry       PROTO((int *, char **, Graphic *));
void          CloseDisplay        PROTO((Graphic *));
void          CreateWindow        PROTO((Graphic *, Window, int, long));
void          DrawBitmap          PROTO((Graphic *, int, int, int, int, char *, int));
unsigned long GetColor            PROTO((Display *, char *, Colormap, unsigned long));
void          LoadFont            PROTO((Graphic *, int *, char **, char *));
void          MakeCursor          PROTO((Graphic *, unsigned int));
void          MakeGC              PROTO((Graphic *));
void          MapWindow           PROTO((Graphic *));
void          NameWindow          PROTO((Graphic *, char *));
Display      *OpenDisplay         PROTO((char *, int *));
void          QuitX               PROTO((Display *, char *, char *));
void          SetNormalHints      PROTO((Graphic *));
Display      *SetUpDisplay        PROTO((Graphic *, int *, char **));
void          SetUpWindow         PROTO((Graphic *, int *, char **));
void          SetWMHints          PROTO((Graphic *, Icon *));
void          TopWindow           PROTO((Graphic *, Icon *));

void          hh_hms              PROTO((char *, double, double, char));
# endif 

Display *SetUpDisplay (int *, char **);
Display *OpenDisplay (char *, int *);
void CheckDisplayName (int *, char **, char *);
void CheckColors (int *, char **);
void SetUpWindow (int *, char **);
void CheckGeometry (int *, char **);
void TopWindow (Icon *);
void QuitX (Display *, char *, char *);
void CreateWindow (Window, int, long);
void MakeCursor (unsigned int);
void CheckFontName (int *, char **, char *);
void LoadFont (int *, char **, char *);
void SetNormalHints ();
void SetWMHints (Icon *);
void NameWindow (char *);
void MapWindow ();
void MakeColormap (int, char **);
void DefineLayout (int, char **);
void PositionPicture (Layout *);
void DrawFrame (Layout *);
int DrawObjects (Layout *);
int DrawObjectN (Layout *, Gobjects *);
void DrawConnect (Layout *, Gobjects *);
void DrawHistogram (Layout *, Gobjects *);
void DrawPoints (Layout *, Gobjects *);
void DrawXErrors (Layout *, Gobjects *);
void DrawYErrors (Layout *, Gobjects *);
void DrawLabels (Layout *);
void Refresh (int);
int CheckPipe ();
int PSit (int);
int PSObjects (Layout *, FILE *);
void PSConnect (Layout *, Gobjects *, FILE *);
void PSHistogram (Layout *, Gobjects *, FILE *);
void PSPoints (Layout *, Gobjects *, FILE *);
void PSXErrors (Layout *, Gobjects *, FILE *);
void PSYErrors (Layout *, Gobjects *, FILE *);
int LoadObject ();
int LoadVectorData (Layout *, int, char *);
int SetLimits ();
int LoadLabels ();
int SetFont ();
int cursor ();
int ErasePlot ();
int Reconfig (XEvent *);
int LoadBox ();
int PSFrame (Layout *, FILE *);
void PSLabels (Layout *, FILE *);
