# include "Ximage.h"
# include "icons/icon.h"

/************** SetUpWindow *************/
void SetUpWindow (Graphic *graphic, int *argc, char **argv) {

  int N;
  Icon icon;

  icon.width = icon_width;
  icon.height = icon_height;
  icon.bits = icon_bits;

  CheckGeometry (argc, argv, graphic);
  TopWindow (graphic, &icon);
  LoadFont (graphic, argc, argv, "fixed"); 

  XFlush (graphic[0].display);
  XSetWindowBackground (graphic[0].display, graphic[0].window, graphic[0].white);

  SetNormalHints (graphic);
  SetWMHints (graphic, &icon);
  NameWindow (graphic, "Ki'i");

  if ((N = get_argument (*argc, argv, "-nomap"))) {
    remove_argument(N, argc, argv);
  } else {
    MapWindow (graphic);
  }  
}



